==> common-3.0.2-sources.jar: com/microsoft/identity/common/internal/logging/ILoggerCallback.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.logging;

/**
 * Interface for apps to configure the external logging and implement the callback to designate the
 * output of the log messages.
 */
public interface ILoggerCallback {
    /**
     * Interface method for apps to hand off each log message as it's generated.
     *
     * @param tag         The TAG for the log message.
     * @param logLevel    The {@link Logger.LogLevel} for the generated message.
     * @param message     The detailed message.
     * @param containsPII True if the log message contains PII, false otherwise.
     */
    void log(String tag, Logger.LogLevel logLevel, String message, boolean containsPII);
}

==> common-3.6.0-sources.jar: com/microsoft/identity/common/internal/logging/ILoggerCallback.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.logging;

/**
 * Interface for apps to configure the external logging and implement the callback to designate the
 * output of the log messages.
 *
 * This class is deprecated. Use {@link com.microsoft.identity.common.logging.ILoggerCallback}.
 */
@Deprecated
public interface ILoggerCallback {
    /**
     * Interface method for apps to hand off each log message as it's generated.
     *
     * @param tag         The TAG for the log message.
     * @param logLevel    The {@link Logger.LogLevel} for the generated message.
     * @param message     The detailed message.
     * @param containsPII True if the log message contains PII, false otherwise.
     */
    void log(String tag, Logger.LogLevel logLevel, String message, boolean containsPII);
}
